@@ -19,67 +19,37 @@
 # Author: Aamir Khan <syst3m.w0rm@gmail.com>
 #
 
-import re
-import sys
 import logging
 
 from django.conf import settings
-from django.contrib import messages
-from django.contrib.auth import logout, authenticate, login
-from django.contrib.auth.decorators import (login_required,
-                                            permission_required,
-                                            user_passes_test)
-from django.contrib.auth.forms import AuthenticationForm
-from hyperkitty.models import UserProfile, Rating
-from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
-from django.http import HttpResponse, HttpResponseRedirect
-from django.shortcuts import render_to_response, redirect
-from django.template import Context, loader, RequestContext
+from django.core.exceptions import SuspiciousOperation
+from django.contrib.auth import logout, authenticate, login
+from django.contrib.auth.decorators import login_required
+from django.contrib.auth.models import User
+from django.shortcuts import render, redirect
+from django.utils.http import is_safe_url
 from django.utils.translation import gettext as _
-from urllib2 import HTTPError
-from urlparse import urlparse
 
-from forms import RegistrationForm
+from hyperkitty.models import UserProfile, Rating, Favorite
+from hyperkitty.views.forms import RegistrationForm, UserProfileForm
 from hyperkitty.lib import get_store
 
 
 logger = logging.getLogger(__name__)
 
 
-def user_logout(request):
-    logout(request)
-    return redirect('user_login')
+FLASH_MESSAGES = {
+    "updated-ok": "The profile was successfully updated.",
+}
 
-def user_login(request, template='login.html'):
-
-    user = None
-    parse_r = urlparse(request.META.get('HTTP_REFERER', 'index'))
-    previous = '%s%s' % (parse_r.path, parse_r.query)
-
-    next_var = request.POST.get('next', request.GET.get('next', previous))
-
-    if request.method == 'POST':
-        form = AuthenticationForm(request.POST)
-        user = authenticate(username=request.POST.get('username'),
-                            password=request.POST.get('password'))
-
-    if user is not None:
-        logger.debug(user)
-        if user.is_active:
-            login(request, user)
-            return redirect(next_var)
-
-    else:
-        form = AuthenticationForm()
-    return render_to_response(template, {'form': form, 'next' : next_var},
-                              context_instance=RequestContext(request))
 
 @login_required
 def user_profile(request, user_email=None):
     if not request.user.is_authenticated():
         return redirect('user_login')
-    t = loader.get_template('user_profile.html')
+
+    store = get_store(request)
 
     # try to render the user profile.
     try:
@@ -88,18 +58,33 @@ def user_profile(request, user_email=None):
     except:
         user_profile = UserProfile.objects.create(user=request.user)
 
+    if request.method == 'POST':
+        form = UserProfileForm(request.POST)
+        if form.is_valid():
+            request.user.first_name = form.cleaned_data["first_name"]
+            request.user.last_name = form.cleaned_data["last_name"]
+            request.user.save()
+            redirect_url = reverse('user_profile')
+            redirect_url += "?msg=updated-ok"
+            return redirect(redirect_url)
+    else:
+        form = UserProfileForm(initial={
+                "first_name": request.user.first_name,
+                "last_name": request.user.last_name,
+                })
+
+    # Votes
     try:
         votes = Rating.objects.filter(user=request.user)
     except Rating.DoesNotExist:
-        votes = {}
-    store = get_store(request)
+        votes = []
     votes_up = []
     votes_down = []
     for vote in votes:
-        message = store.get_message_by_id_from_list(
-                vote.list_address, vote.message_id)
+        message = store.get_message_by_hash_from_list(
+                vote.list_address, vote.messageid)
         vote_data = {"list_address": vote.list_address,
-                     "message_id": vote.message_id,
+                     "messageid": vote.messageid,
                      "message": message,
                     }
         if vote.vote == 1:
@@ -107,26 +92,52 @@ def user_profile(request, user_email=None):
         elif vote.vote == -1:
             votes_down.append(vote_data)
 
-    c = RequestContext(request, {
+    # Favorites
+    try:
+        favorites = Favorite.objects.filter(user=request.user)
+    except Favorite.DoesNotExist:
+        favorites = []
+    for fav in favorites:
+        thread = store.get_thread(fav.list_address, fav.threadid)
+        fav.thread = thread
+
+    flash_messages = []
+    flash_msg = request.GET.get("msg")
+    if flash_msg:
+        flash_msg = { "type": "success", "msg": FLASH_MESSAGES[flash_msg] }
+        flash_messages.append(flash_msg)
+
+    context = {
         'user_profile' : user_profile,
+        'form': form,
         'votes_up': votes_up,
         'votes_down': votes_down,
-        'use_mockups': settings.USE_MOCKUPS,
-    })
-
-    return HttpResponse(t.render(c))
+        'favorites': favorites,
+        'flash_messages': flash_messages,
+    }
+    return render(request, "user_profile.html", context)
 
 
 def user_registration(request):
+    if not settings.USE_INTERNAL_AUTH:
+        raise SuspiciousOperation
+    redirect_to = request.REQUEST.get("next", reverse("root"))
+    if not is_safe_url(url=redirect_to, host=request.get_host()):
+        redirect_to = settings.LOGIN_REDIRECT_URL
+
+
     if request.user.is_authenticated():
         # Already registered, redirect back to index page
-        return redirect('index')
+        return redirect(redirect_to)
 
     if request.POST:
         form = RegistrationForm(request.POST)
         if form.is_valid():
-            # Save the user data.
-            form.save(form.cleaned_data)
+            u = User.objects.create_user(form.cleaned_data['username'],
+                                         form.cleaned_data['email'],
+                                         form.cleaned_data['password1'])
+            u.is_active = True
+            u.save()
             user = authenticate(username=form.cleaned_data['username'],
                                 password=form.cleaned_data['password1'])
 
@@ -134,9 +145,12 @@ def user_registration(request):
                 logger.debug(user)
                 if user.is_active:
                     login(request, user)
-                    return redirect('index')
+                    return redirect(redirect_to)
     else:
         form = RegistrationForm()
 
-    return render_to_response('register.html', {'form': form}, context_instance=RequestContext(request))
-
+    context = {
+        'form': form,
+        'next': redirect_to,
+    }
+    return render(request, 'register.html', context)
