@@ -25,6 +25,7 @@ from django.contrib.auth.models import User
 from django.utils.safestring import mark_safe
 
 
+
 def isValidUsername(username):
         try:
             User.objects.get(username=username)
@@ -33,27 +34,34 @@ def isValidUsername(username):
         raise validators.ValidationError('The username "%s" is already taken.' % username)
 
 
+
 class RegistrationForm(forms.Form):
 
-    username =  forms.CharField(label='username', help_text=None,
-                widget=forms.TextInput(
-                    attrs={'placeholder': 'username...'}
-                    ), required = True, validators=[isValidUsername]
-                )
+    username =  forms.CharField(widget=forms.TextInput, required=True,
+                                validators=[isValidUsername])
 
     email     = forms.EmailField(required=True)
 
-    password1 = forms.CharField(widget=forms.PasswordInput)
+    password1 = forms.CharField(widget=forms.PasswordInput,
+                                required=True, label="Password")
 
-    password2 = forms.CharField(widget=forms.PasswordInput)
+    password2 = forms.CharField(widget=forms.PasswordInput,
+                                required=True, label="Confirm password")
+
+    def clean(self):
+        cleaned_data = super(RegistrationForm, self).clean()
+        if cleaned_data.get("password1") != cleaned_data.get("password2"):
+            self._errors["password2"] = self.error_class(["Passwords do not match."])
+            del cleaned_data["password1"]
+            del cleaned_data["password2"]
+        return cleaned_data
+
+
+
+class UserProfileForm(forms.Form):
+    first_name = forms.CharField()
+    last_name = forms.CharField()
 
-    def save(self, new_user_data):
-        u = User.objects.create_user(new_user_data['username'],
-                                     new_user_data['email'],
-                                     new_user_data['password1'])
-        u.is_active = True
-        u.save()
-        return u
 
 
 class TextInputWithButton(forms.TextInput):
@@ -74,16 +82,19 @@ class TextInputWithButton(forms.TextInput):
                         initial_rendering, button, u'</span>'])
 
 
+
 class AddTagForm(forms.Form):
     tag =  forms.CharField(label='', help_text=None,
                 widget=TextInputWithButton(
                     attrs={'placeholder': 'Add a tag...',
-                           'class': 'span2',
+                           'class': 'input-medium',
                            'button_text': 'Add'}
                     )
                 )
     from_url = forms.CharField(widget=forms.HiddenInput, required=False)
 
+
+
 class SearchForm(forms.Form):
     target =  forms.CharField(label='', help_text=None,
                 widget=forms.Select(
@@ -101,3 +112,10 @@ class SearchForm(forms.Form):
                 )
 
 
+
+class ReplyForm(forms.Form):
+    message = forms.CharField(widget=forms.Textarea, label="")
+
+class PostForm(forms.Form):
+    subject = forms.CharField()
+    message = forms.CharField(widget=forms.Textarea)
