@@ -20,124 +20,88 @@
 # Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
 
-import re
-import os
-import json
-import urllib
-import logging
-from calendar import timegm
-from datetime import datetime, timedelta
-from urlparse import urljoin
-from collections import namedtuple
+import datetime
+from collections import namedtuple, defaultdict
 
-import django.utils.simplejson as simplejson
-from django.http import HttpResponse, HttpResponseRedirect
-from django.template import RequestContext, loader
+from django.shortcuts import redirect, render
 from django.conf import settings
 from django.core.urlresolvers import reverse
-from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger, InvalidPage
-from django.contrib.auth.decorators import (login_required,
-                                            permission_required,
-                                            user_passes_test)
+from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
+from django.utils import formats
+from django.utils.dateformat import format as date_format
 
-from hyperkitty.models import Rating, Tag
-from hyperkitty.lib import get_months, get_store
-from forms import *
+from hyperkitty.models import Tag, Favorite
+from hyperkitty.lib import get_months, get_store, get_display_dates
+from hyperkitty.lib.voting import get_votes
+from forms import SearchForm
 
 
-logger = logging.getLogger(__name__)
-
 if settings.USE_MOCKUPS:
     from hyperkitty.lib.mockup import generate_top_author, generate_thread_per_category
 
 
+FLASH_MESSAGES = {
+    "sent-ok": "The message has been sent successfully.",
+}
+
 
 def archives(request, mlist_fqdn, year=None, month=None, day=None):
-    # No year/month: past 32 days
-    # year and month: find the 32 days for that month
-    # @TODO : modify url.py to account for page number
+    if year is None and month is None:
+        today = datetime.date.today()
+        return redirect(reverse(
+                'archives_with_month', kwargs={
+                    "mlist_fqdn": mlist_fqdn,
+                    'year': today.year,
+                    'month': today.month}))
 
-    end_date = None
-    if year or month or day:
-        try:
-            start_day = 1
-            end_day = 1
-            start_month = int(month)
-            end_month = int(month) + 1
-            start_year = int(year)
-            end_year = int(year)
-            if day:
-                start_day = int(day)
-                end_day = start_day + 1
-                end_month = start_month
-            if start_month == 12:
-                end_month = 1
-                end_year = start_year + 1
-
-            begin_date = datetime(start_year, start_month, start_day)
-            end_date = datetime(end_year, end_month, end_day)
-            month_string = begin_date.strftime('%B %Y')
-        except ValueError, err:
-            print err
-            logger.error('Wrong format given for the date')
-
-    if not end_date:
-        today = datetime.utcnow()
-        begin_date = datetime(today.year, today.month, 1)
-        end_date = datetime(today.year, today.month + 1, 1)
-        month_string = 'Past thirty days'
-
-    search_form = SearchForm(auto_id=False)
-    t = loader.get_template('month_view.html')
+    begin_date, end_date = get_display_dates(year, month, day)
     store = get_store(request)
     mlist = store.get_list(mlist_fqdn)
-    all_threads = store.get_threads(mlist_fqdn, start=begin_date,
-                                    end=end_date)
+    threads = store.get_threads(mlist_fqdn, start=begin_date, end=end_date)
+    if day is None:
+        list_title = date_format(begin_date, "F Y")
+        no_results_text = "for this month"
+    else:
+        #list_title = date_format(begin_date, settings.DATE_FORMAT)
+        list_title = formats.date_format(begin_date) # works with i18n
+        no_results_text = "for this day"
+    extra_context = {
+        'month': begin_date,
+        'month_num': begin_date.month,
+        "list_title": list_title.capitalize(),
+        "no_results_text": no_results_text,
+    }
+    return _thread_list(request, mlist, threads, extra_context=extra_context)
+
+
+def _thread_list(request, mlist, threads, template_name='thread_list.html', extra_context={}):
+    store = get_store(request)
+    search_form = SearchForm(auto_id=False)
 
     participants = set()
-    #cnt = 0
-    for thread in all_threads:
+    for thread in threads:
         participants.update(thread.participants)
 
-        highestlike = 0
-        highestdislike = 0
-
+        # Votes
         totalvotes = 0
         totallikes = 0
         totaldislikes = 0
-
-        for message_id in thread.email_ids:
-            # Extract all the votes for this message
-            try:
-                votes = Rating.objects.filter(messageid=message_id)
-            except Rating.DoesNotExist:
-                votes = {}
-
-            likes = 0
-            dislikes = 0
-
-            for vote in votes:
-                if vote.vote == 1:
-                    likes = likes + 1
-                elif vote.vote == -1:
-                    dislikes = dislikes + 1
-                else:
-                    pass
-
+        for message_id_hash in thread.email_id_hashes:
+            likes, dislikes, myvote = get_votes(message_id_hash, request.user)
             totallikes = totallikes + likes
             totalvotes = totalvotes + likes + dislikes
             totaldislikes = totaldislikes + dislikes
-
+            if message_id_hash == thread.thread_id:
+                # Starting email: same id as the thread_id
+                thread.myvote = myvote
         try:
             thread.likes = totallikes / totalvotes
-        except:
+        except ZeroDivisionError:
             thread.likes = 0
-
         try:
             thread.dislikes = totaldislikes / totalvotes
-        except:
+        except ZeroDivisionError:
             thread.dislikes = 0
-
         thread.likestatus = "neutral"
         if thread.likes - thread.dislikes >= 10:
             thread.likestatus = "likealot"
@@ -146,14 +110,30 @@ def archives(request, mlist_fqdn, year=None, month=None, day=None):
         #elif thread.likes - thread.dislikes < 0:
         #    thread.likestatus = "dislike"
 
-        #threads[cnt] = thread
-        #cnt = cnt + 1
+        # Favorites
+        thread.favorite = False
+        if request.user.is_authenticated():
+            try:
+                Favorite.objects.get(list_address=mlist.name,
+                                     threadid=thread.thread_id,
+                                     user=request.user)
+            except Favorite.DoesNotExist:
+                pass
+            else:
+                thread.favorite = True
 
-    paginator = Paginator(all_threads, 10)
-    pageNo = request.GET.get('page')
+        # Tags
+        try:
+            thread.tags = Tag.objects.filter(threadid=thread.thread_id,
+                                             list_address=mlist.name)
+        except Tag.DoesNotExist:
+            thread.tags = []
 
+    all_threads = threads
+    paginator = Paginator(threads, 10)
+    page_num = request.GET.get('page')
     try:
-        threads = paginator.page(pageNo)
+        threads = paginator.page(page_num)
     except PageNotAnInteger:
         # If page is not an integer, deliver first page.
         threads = paginator.page(1)
@@ -161,72 +141,53 @@ def archives(request, mlist_fqdn, year=None, month=None, day=None):
         # If page is out of range (e.g. 9999), deliver last page of results.
         threads = paginator.page(paginator.num_pages)
 
+    flash_messages = []
+    flash_msg = request.GET.get("msg")
+    if flash_msg:
+        flash_msg = { "type": "success", "msg": FLASH_MESSAGES[flash_msg] }
+        flash_messages.append(flash_msg)
 
-    archives_length = get_months(store, mlist_fqdn)
-
-    c = RequestContext(request, {
+    context = {
         'mlist' : mlist,
-        'objects': threads.object_list,
-        'page': pageNo,
-        'has_previous': threads.has_previous(),
-        'has_next': threads.has_next(),
-        'previous': threads.previous_page_number(),
-        'next': threads.next_page_number(),
-        'is_first': pageNo == 1,
-        'is_last': pageNo == paginator.num_pages,
-        'list_address': mlist_fqdn,
+        'current_page': page_num,
         'search_form': search_form,
-        'month': begin_date,
-        'month_num': begin_date.month,
-        'month_participants': len(participants),
-        'month_discussions': len(all_threads),
         'threads': threads,
-        'pages' : paginator.object_list,
-        'archives_length': archives_length,
-        'use_mockups': settings.USE_MOCKUPS,
-    })
-    return HttpResponse(t.render(c))
+        'participants': len(participants),
+        'months_list': get_months(store, mlist.name),
+        'flash_messages': flash_messages,
+    }
+    context.update(extra_context)
+    return render(request, template_name, context)
 
-def list(request, mlist_fqdn=None):
+
+
+def overview(request, mlist_fqdn=None):
     if not mlist_fqdn:
-        return HttpResponseRedirect('/')
-    t = loader.get_template('recent_activities.html')
+        return redirect('/')
     search_form = SearchForm(auto_id=False)
 
     # Get stats for last 30 days
-    today = datetime.utcnow()
-    end_date = datetime(today.year, today.month, today.day)
-    begin_date = end_date - timedelta(days=32)
+    today = datetime.datetime.utcnow()
+    # the upper boundary is excluded in the search, add one day
+    end_date = today + datetime.timedelta(days=1)
+    begin_date = end_date - datetime.timedelta(days=32)
 
     store = get_store(request)
     mlist = store.get_list(mlist_fqdn)
-    threads_result = store.get_threads(list_name=mlist_fqdn, start=begin_date,
+    threads_result = store.get_threads(list_name=mlist.name, start=begin_date,
         end=end_date)
 
     threads = []
     Thread = namedtuple('Thread', ["thread_id", "subject", "participants",
                                    "length", "date_active"])
     participants = set()
-    dates = {}
     for thread_obj in threads_result:
         thread = Thread(thread_obj.thread_id, thread_obj.subject,
                         thread_obj.participants, len(thread_obj),
                         thread_obj.date_active)
-        threads.append(thread)
-
-        month = thread.date_active.month
-        if month < 10:
-            month = '0%s' % month
-        day = thread.date_active.day
-        if day < 10:
-            day = '0%s' % day
-        key = '%s%s%s' % (thread.date_active.year, month, day)
-        if key in dates:
-            dates[key] = dates[key] + 1
-        else:
-            dates[key] = 1
         # Statistics on how many participants and threads this month
         participants.update(thread.participants)
+        threads.append(thread)
 
     # top threads are the one with the most answers
     top_threads = sorted(threads, key=lambda t: t.length, reverse=True)
@@ -234,8 +195,6 @@ def list(request, mlist_fqdn=None):
     # active threads are the ones that have the most recent posting
     active_threads = sorted(threads, key=lambda t: t.date_active, reverse=True)
 
-    archives_length = get_months(store, mlist_fqdn)
-
     # top authors are the ones that have the most kudos.  How do we determine
     # that?  Most likes for their post?
     if settings.USE_MOCKUPS:
@@ -245,13 +204,23 @@ def list(request, mlist_fqdn=None):
     else:
         authors = []
 
-    # Get the list activity per day
+    # List activity
+    # Use get_messages and not get_threads to count the emails, because
+    # recently active threads include messages from before the start date
+    emails_in_month = store.get_messages(list_name=mlist.name,
+                                         start=begin_date, end=end_date)
+    dates = defaultdict(lambda: 0) # no activity by default
+    for email in emails_in_month:
+        date_str = email.date.strftime("%Y-%m-%d")
+        dates[date_str] = dates[date_str] + 1
     days = dates.keys()
     days.sort()
-    dates_string = ["%s/%s/%s" % (key[0:4], key[4:6], key[6:8]) for key in days]
-    evolution = [dates[key] for key in days]
+    evolution = [dates[d] for d in days]
     if not evolution:
         evolution.append(0)
+    archives_baseurl = reverse("archives_latest",
+                               kwargs={'mlist_fqdn': mlist.name})
+    archives_baseurl = archives_baseurl.rpartition("/")[0]
 
     # threads per category is the top thread titles in each category
     if settings.USE_MOCKUPS:
@@ -259,64 +228,19 @@ def list(request, mlist_fqdn=None):
     else:
         threads_per_category = {}
 
-    c = RequestContext(request, {
+    context = {
         'mlist' : mlist,
-        'list_address': mlist_fqdn,
         'search_form': search_form,
-        'month': None,
-        'month_participants': len(participants),
-        'month_discussions': len(threads),
         'top_threads': top_threads[:5],
         'most_active_threads': active_threads[:5],
         'top_author': authors,
         'threads_per_category': threads_per_category,
-        'archives_length': archives_length,
+        'months_list': get_months(store, mlist.name),
         'evolution': evolution,
-        'dates_string': dates_string,
-        'use_mockups': settings.USE_MOCKUPS,
-    })
-    return HttpResponse(t.render(c))
-
-
-def _search_results_page(request, mlist_fqdn, threads, search_type,
-                         page=1, num_threads=25, limit=None):
-    search_form = SearchForm(auto_id=False)
-    t = loader.get_template('search.html')
-    list_name = mlist_fqdn.split('@')[0]
-    res_num = len(threads)
-
-    participants = set()
-    for msg in threads:
-        participants.add(msg.sender_name)
-
-    paginator = Paginator(threads, num_threads)
-
-    #If page request is out of range, deliver last page of results.
-    try:
-        threads = paginator.page(page)
-    except (EmptyPage, InvalidPage):
-        threads = paginator.page(paginator.num_pages)
-
-    store = get_store(request)
-    cnt = 0
-    for thread in threads.object_list:
-        #msg.email = msg.sender_email.strip()
-        # Statistics on how many participants and threads this month
-        participants.update(thread.participants)
-        threads.object_list[cnt] = thread
-        cnt = cnt + 1
-
-    c = RequestContext(request, {
-        'list_name' : list_name,
-        'list_address': mlist_fqdn,
-        'search_form': search_form,
-        'month': search_type,
-        'month_participants': len(participants),
-        'month_discussions': res_num,
-        'threads': threads,
-        'full_path': request.get_full_path(),
-    })
-    return HttpResponse(t.render(c))
+        'days': days,
+        'archives_baseurl': archives_baseurl,
+    }
+    return render(request, "recent_activities.html", context)
 
 
 def search(request, mlist_fqdn):
@@ -332,13 +256,13 @@ def search(request, mlist_fqdn):
             url += '%s/' % page
     else:
         url = reverse('search_list', kwargs={"mlist_fqdn": mlist_fqdn})
-    return HttpResponseRedirect(url)
+    return redirect(url)
 
 
 def search_keyword(request, mlist_fqdn, target, keyword, page=1):
+    store = get_store(request)
     ## Should we remove the code below?
     ## If urls.py does it job we should never need it
-    store = get_store(request)
     if not keyword:
         keyword = request.GET.get('keyword')
     if not target:
@@ -359,21 +283,24 @@ def search_keyword(request, mlist_fqdn, target, keyword, page=1):
     return _search_results_page(request, mlist_fqdn, threads, 'Search', page)
 
 
-def search_tag(request, mlist_fqdn, tag=None, page=1):
+def search_tag(request, mlist_fqdn, tag):
     '''Returns threads having a particular tag'''
-
-    store = get_store(settings.KITTYSTORE_URL)
-    list_name = mlist_fqdn.split('@')[0]
+    store = get_store(request)
+    mlist = store.get_list(mlist_fqdn)
 
     try:
-        thread_ids = Tag.objects.filter(tag=tag)
+        tags = Tag.objects.filter(tag=tag)
     except Tag.DoesNotExist:
-        thread_ids = {}
+        tags = {}
 
     threads = []
-    for thread_id in thread_ids:
-        threads.append(store.get_thread(mlist_fqdn, thread_id))
+    for t in tags:
+        threads.append(store.get_thread(mlist_fqdn, t.threadid))
 
-    return _search_results_page(request, mlist_fqdn, threads,
-        'Tag search', page, limit=50)
+    extra_context = {
+        "tag": tag,
+        "list_title": "Search results for tag \"%s\"" % tag,
+        "no_results_text": "for this tag",
+    }
+    return _thread_list(request, mlist, threads, extra_context=extra_context)
 
