@@ -19,40 +19,22 @@
 # Author: Aamir Khan <syst3m.w0rm@gmail.com>
 #
 
-import re
-import os
-import json
-import urllib
-from calendar import timegm
-from datetime import datetime, timedelta
-from urlparse import urljoin
-
-import django.utils.simplejson as simplejson
-from django.http import HttpResponse, HttpResponseRedirect
-from django.template import RequestContext, loader
+from django.shortcuts import render
 from django.conf import settings
-from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger, InvalidPage
-from django.contrib.auth.decorators import (login_required,
-                                            permission_required,
-                                            user_passes_test)
 
-from hyperkitty.models import Rating
 from hyperkitty.lib import get_store
-from forms import *
+from forms import SearchForm
 
 
 def index(request):
-    t = loader.get_template('index.html')
-    search_form = SearchForm(auto_id=False)
-
     base_url = settings.MAILMAN_API_URL % {
         'username': settings.MAILMAN_USER, 'password': settings.MAILMAN_PASS}
 
     store = get_store(request)
-    list_data = store.get_list_names()
+    lists = store.get_lists()
 
-    c = RequestContext(request, {
-        'lists': list_data,
-        'search_form': search_form,
-        })
-    return HttpResponse(t.render(c))
+    context = {
+        'all_lists': lists,
+        'search_form': SearchForm(auto_id=False),
+        }
+    return render(request, "index.html", context)
