@@ -21,81 +21,71 @@
 #
 
 import datetime
+from collections import namedtuple
 
-import django.utils.simplejson as simplejson
+import django.utils.simplejson as json
 
-from django.http import HttpResponse, HttpResponseRedirect, Http404
-from django.template import RequestContext, loader
+from django.http import HttpResponse, Http404
 from django.conf import settings
-from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger, InvalidPage
+from django.template import RequestContext, loader
+from django.shortcuts import render
 from django.core.urlresolvers import reverse
-from django.utils.datastructures import SortedDict
-from django.contrib.auth.decorators import (login_required,
-                                            permission_required,
-                                            user_passes_test)
+from django.core.exceptions import SuspiciousOperation
 
-from hyperkitty.models import Rating, Tag
-#from hyperkitty.lib.mockup import *
-from forms import *
+from hyperkitty.models import Tag, Favorite
+from forms import SearchForm, AddTagForm, ReplyForm
 from hyperkitty.lib import get_months, get_store, stripped_subject
+from hyperkitty.lib.voting import set_message_votes
 
 
-def thread_index(request, mlist_fqdn, threadid):
+def thread_index(request, mlist_fqdn, threadid, month=None, year=None):
     ''' Displays all the email for a given thread identifier '''
     search_form = SearchForm(auto_id=False)
-    t = loader.get_template('thread.html')
     store = get_store(request)
     thread = store.get_thread(mlist_fqdn, threadid)
     if not thread:
         raise Http404
     prev_thread, next_thread = store.get_thread_neighbors(mlist_fqdn, threadid)
 
+    if "sort" in request.GET and request.GET["sort"] == "date":
+        sort_mode = "date"
+        emails = thread.emails
+    else:
+        sort_mode = "thread"
+        emails = thread.emails_by_reply
+
     participants = {}
-    cnt = 0
-
-    for message in thread.emails:
+    for email in emails:
         # Extract all the votes for this message
-        try:
-            votes = Rating.objects.filter(messageid=message.message_id)
-        except Rating.DoesNotExist:
-            votes = {}
-
-        likes = 0
-        dislikes = 0
-
-        for vote in votes:
-            if vote.vote == 1:
-                likes = likes + 1
-            elif vote.vote == -1:
-                dislikes = dislikes + 1
-            else:
-                pass
-
-        message.votes = votes
-        message.likes = likes
-        message.dislikes = dislikes
-        message.likestatus = "neutral"
-        if message.likes - message.dislikes >= 10:
-            message.likestatus = "likealot"
-        elif message.likes - message.dislikes > 0:
-            message.likestatus = "like"
-        #elif message.likes - message.dislikes < 0:
-        #    message.likestatus = "dislike"
-
+        set_message_votes(email, request.user)
 
         # Statistics on how many participants and messages this month
-        participants[message.sender_name] = message.sender_email
-        cnt = cnt + 1
+        participants[email.sender_name] = email.sender_email
+
+        if sort_mode == "thread":
+            email.level = email.thread_depth - 1 # replies start ragged left
+            if email.level > 5:
+                email.level = 5
 
-    archives_length = get_months(store, mlist_fqdn)
     from_url = reverse("thread", kwargs={"mlist_fqdn":mlist_fqdn,
                                          "threadid":threadid})
+    # Tags
     tag_form = AddTagForm(initial={'from_url' : from_url})
-
     try:
         tags = Tag.objects.filter(threadid=threadid, list_address=mlist_fqdn)
     except Tag.DoesNotExist:
-        tags = {}
+        tags = []
+
+    # Favorites
+    fav_action = "add"
+    if request.user.is_authenticated():
+        try:
+            Favorite.objects.get(list_address=mlist_fqdn, threadid=threadid,
+                                 user=request.user)
+        except Favorite.DoesNotExist:
+            pass
+        else:
+            fav_action = "rm"
 
     # Extract relative dates
     today = datetime.date.today()
@@ -105,37 +95,36 @@ def thread_index(request, mlist_fqdn, threadid):
     mlist = store.get_list(mlist_fqdn)
     subject = stripped_subject(mlist, thread.starting_email.subject)
 
-    c = RequestContext(request, {
+    context = {
         'mlist' : mlist,
         'threadid' : threadid,
         'subject': subject,
         'tags' : tags,
-        'list_address': mlist_fqdn,
         'search_form': search_form,
         'addtag_form': tag_form,
-        'month': 'Thread',
+        'month': thread.date_active,
         'participants': participants,
-        'answers': cnt,
         'first_mail': thread.starting_email,
-        'replies': list(thread.emails)[1:],
+        'replies': list(emails)[1:],
         'neighbors': (prev_thread, next_thread),
-        'archives_length': archives_length,
+        'months_list': get_months(store, mlist.name),
         'days_inactive': days_inactive.days,
         'days_old': days_old.days,
-        'use_mockups': settings.USE_MOCKUPS,
-    })
-    return HttpResponse(t.render(c))
+        'sort_mode': sort_mode,
+        'fav_action': fav_action,
+        'reply_form': ReplyForm(),
+    }
+    return render(request, "thread.html", context)
 
 
-def add_tag(request, mlist_fqdn, hashid):
+def add_tag(request, mlist_fqdn, threadid):
     """ Add a tag to a given thread. """
     if not request.user.is_authenticated():
         return HttpResponse('You must be logged in to add a tag',
                             content_type="text/plain", status=403)
 
     if request.method != 'POST':
-        return HttpResponse("Something went wrong here",
-                            content_type="text/plain", status=500)
+        raise SuspiciousOperation
 
     form = AddTagForm(request.POST)
     if not form.is_valid():
@@ -143,20 +132,50 @@ def add_tag(request, mlist_fqdn, hashid):
                             content_type="text/plain", status=500)
     tag = form.data['tag']
     try:
-        tag_obj = Tag.objects.get(threadid=hashid,
+        tag_obj = Tag.objects.get(threadid=threadid,
                                   list_address=mlist_fqdn, tag=tag)
     except Tag.DoesNotExist:
-        tag_obj = Tag(list_address=mlist_fqdn, threadid=hashid, tag=tag)
+        tag_obj = Tag(list_address=mlist_fqdn, threadid=threadid, tag=tag)
         tag_obj.save()
 
     # Now refresh the tag list
-    tags = Tag.objects.filter(threadid=hashid, list_address=mlist_fqdn)
+    tags = Tag.objects.filter(threadid=threadid, list_address=mlist_fqdn)
+    FakeMList = namedtuple("MailingList", ["name"])
     t = loader.get_template('threads/tags.html')
     html = t.render(RequestContext(request, {
             "tags": tags,
-            "list_address": mlist_fqdn}))
+            "mlist": FakeMList(name=mlist_fqdn)}))
 
     response = {"tags": [ t.tag for t in tags ], "html": html}
-    return HttpResponse(simplejson.dumps(response),
+    return HttpResponse(json.dumps(response),
                         mimetype='application/javascript')
 
+
+
+def favorite(request, mlist_fqdn, threadid):
+    """ Add or remove from favorites"""
+    if not request.user.is_authenticated():
+        return HttpResponse('You must be logged in to have favorites',
+                            content_type="text/plain", status=403)
+
+    if request.method != 'POST':
+        raise SuspiciousOperation
+
+    props = dict(list_address=mlist_fqdn, threadid=threadid, user=request.user)
+    if request.POST["action"] == "add":
+        try:
+            fav = Favorite.objects.get(**props)
+        except Favorite.DoesNotExist:
+            fav = Favorite(**props)
+        fav.save()
+    elif request.POST["action"] == "rm":
+        try:
+            fav = Favorite.objects.get(**props)
+        except Favorite.DoesNotExist:
+            pass
+        else:
+            fav.delete()
+    else:
+        raise SuspiciousOperation
+    return HttpResponse("success", mimetype='text/plain')
+
